NAME
Data::Record::Serialize::Util - Useful things
VERSION
version 2.05
SUBROUTINES
populate_set
\@list = populate_set( \@values, \@input );
Apply set-operations to a sequence of input values and return the resulting array reference.
@input must be drawn from the following set of values:
elements of
@valuesThe
+or-charactersElements of
@valuesprefixed with+or-.
@input is processed in order:
If the first value is
-or begins with-, the output set is initialized with the contents of@valuesA bare
+replaces the current contents with the contents of@values, in order.A bare
-clears the output set.A bare value or a value prefixed with
+is appended.A value prefixed with
-is removed from the output set.
The result preserves insertion order and removes leading duplicates.
SUPPORT
Bugs
Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
Source is available at
https://gitlab.com/djerius/data-record-serialize
and may be cloned from
https://gitlab.com/djerius/data-record-serialize.git
SEE ALSO
Please see those modules/websites for more information related to this module.
AUTHOR
Diab Jerius <djerius@cpan.org>
COPYRIGHT AND LICENSE
This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
This is free software, licensed under:
The GNU General Public License, Version 3, June 2007